@@ -34,6 +34,8 @@
 #pragma GCC poison PETSC_PETSC_HAVE_MEMMOVE
 #pragma GCC poison PETSC_PETSC_HAVE_MKSTEMP
 #pragma GCC poison PETSC_PETSC_HAVE_MPIUNI
+#pragma GCC poison PETSC_PETSC_HAVE_MPI_COUNT
+#pragma GCC poison PETSC_PETSC_HAVE_MPI_LARGE_COUNT
 #pragma GCC poison PETSC_PETSC_HAVE_MPI_REDUCE_LOCAL
 #pragma GCC poison PETSC_PETSC_HAVE_OPENBLAS
 #pragma GCC poison PETSC_PETSC_HAVE_OPENBLAS_SET_NUM_THREADS
